@@ -6,6 +6,8 @@
 # Author:  Hengyue Li
 #──────────────────────────
 # Version:
+#          2022/11/18
+#               fix bug in __CreateMuteDynamicForwordConnection, bind_address is not defined
 #          2022/03/18
 #               new progress bar for upload and download
 #          2022/02/26
@@ -492,7 +494,7 @@ class SSH_Operation(object):
 
     def __CreateMuteDynamicForwordConnection(self,localPort):
         self.connectIfNotConnected()
-        self.ssh.open_socks_proxy(bind_address=bind_address, port=localPort)
+        self.ssh.open_socks_proxy(bind_address='127.0.0.1', port=localPort)
 
 
     def PortForward(self,localPort,targetHost,targetPort):
